/***********************************************************
 * $Id$
 *
 * FancyLibs GPSD Client
 *
 * Copyright (C) 2014 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSPSDCLIENTDEVICE_H_
#define FANCYSPSDCLIENTDEVICE_H_

#include <fancygpsdclientmessage.h>
#include <fancyutctimestamp.h>
#include <fancystring.h>

namespace Fancy {
namespace GpsdClient {

/**
 * <pre>
 * "{\"class\":\"DEVICE\",\"path\":\"/dev/ttyUSB0\",\"activated\":1269960793.97,"
			"\"driver\":\"SiRF binary\",\"native\":1,\"bps\":4800,"
			"\"parity\":\"N\",\"stopbits\":1,\"cycle\":1.00}\r\n"
 * </pre>
 */
class FANCYGPSDCLIENT_API Device : public Message
 {
 Fancy::String::ptr_t path;
 Fancy::UtcTimestamp::ptr_t activated;
 Fancy::String::ptr_t driver;
 Fancy::Number::ptr_t native;
 Fancy::Number::ptr_t bps;
 Fancy::String::ptr_t parity;
 Fancy::Number::ptr_t stopbits;
 Fancy::Number::ptr_t cycle;

 public:

 typedef Fancy::ObjPtr<Device> ptr_t;
 static ptr_t newInstance();
 static Fancy::Serializable::ptr_t newSerializableInstance();
 static const char* getSerialID_s();
 static const char* getSuperSerialID_s();
 const char* getSerialID() const;
 const char* getSuperSerialID() const;

 void writeFields(const ObjPtr<Serializer>& serializer) const;
 ObjPtr<Serializable> readFields(const ObjPtr<Serializer>& serializer, int64_t serialVersionUID);


 Fancy::String::ptr_t getPath() const;
 void setPath(const Fancy::String::ptr_t &path);
 Fancy::UtcTimestamp::ptr_t getActivated() const;
 void setActivated(const Fancy::UtcTimestamp::ptr_t &activated);
 Fancy::Number::ptr_t getBps() const;
 void setBps(const Fancy::Number::ptr_t &bps);
 Fancy::Number::ptr_t getCycle() const;
 void setCycle(const Fancy::Number::ptr_t &cycle);
 Fancy::String::ptr_t getDriver() const;
 void setDriver(const Fancy::String::ptr_t &driver);
 Fancy::Number::ptr_t getNative() const;
 void setNative(const Fancy::Number::ptr_t &native);
 Fancy::String::ptr_t getParity() const;
 void setParity(const Fancy::String::ptr_t &parity);
 Fancy::Number::ptr_t getStopbits() const;
 void setStopbits(const Fancy::Number::ptr_t &stopbits);

 protected:
 Device();
 virtual ~Device();
 };

} /* namespace GpsdClient */
} /* namespace Fancy */

#endif /* FANCYSPSDCLIENTVERSION_H_ */
