/***********************************************************
 * $Id$
 *
 * FancyLibs GPSD Client
 *
 * Copyright (C) 2014 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSPSDCLIENTSATELLITE_H_
#define FANCYSPSDCLIENTSATELLITE_H_

#include <fancygpsdclientmessage.h>
#include <fancystring.h>
#include <fancyutctimestamp.h>

namespace Fancy {
namespace GpsdClient {

/**
 * <pre>
Name	Always?	Type	Description
PRN	Yes	numeric	PRN ID of the satellite. 1-63 are GNSS satellites, 64-96 are GLONASS satellites, 100-164 are SBAS satellites
az	Yes	numeric	Azimuth, degrees from true north.
el	Yes	numeric	Elevation in degrees.
ss	Yes	numeric	Signal strength in dB.
used	Yes	boolean	Used in current solution? (SBAS/WAAS/EGNOS satellites may be flagged used if the solution has corrections from them, but not all drivers make this information available.)

 * </pre>
 */
class FANCYGPSDCLIENT_API Satellite: public Message {
	int32_t PRN;
	double el;
	double az;
	double ss;
	bool used;

public:
	typedef Fancy::ObjPtr<Satellite> ptr_t;
	static ptr_t newInstance();
	static Fancy::Serializable::ptr_t newSerializableInstance();
	static const char* getSerialID_s();
	static const char* getSuperSerialID_s();
	const char* getSerialID() const;
	const char* getSuperSerialID() const;
	void writeFields(const ObjPtr<Serializer>& serializer) const;
	ObjPtr<Serializable> readFields(const ObjPtr<Serializer>& serializer, int64_t serialVersionUID);

	int32_t getPRN() const;
	void setPRN(int32_t PRN);
	double getEl() const;
	void setEl(double el);
	double getAz() const;
	void setAz(double az);
	double getSs() const;
	void setSs(double ss);
	void setUsed(bool used);
	bool isUsed() const;

protected:
	Satellite();
	virtual ~Satellite();
};

} /* namespace GpsdClient */
} /* namespace Fancy */

#endif /* FANCYSPSDCLIENTVERSION_H_ */
