/***********************************************************
 * $Id$
 *
 * FancyLibs GPSD Client
 *
 * Copyright (C) 2014 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSPSDCLIENTSKY_H_
#define FANCYSPSDCLIENTSKY_H_

#include <fancygpsdclientmessage.h>
#include <fancystring.h>
#include <fancyutctimestamp.h>
#include <fancylist.h>

namespace Fancy {
namespace GpsdClient {

/**
 * <pre>
class	Yes	string	Fixed: "SKY"
tag	No	string	Type tag associated with this GPS sentence; from an NMEA device this is just the NMEA sentence type.
device	No	string	Name of originating device
time	No	numeric	Time/date stamp in ISO8601 format, UTC. May have a fractional part of up to .001sec precision.
xdop	No	numeric	Longitudinal dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get an error estimate.
ydop	No	numeric	Latitudinal dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get an error estimate.
vdop	No	numeric	Altitude dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get an error estimate.
tdop	No	numeric	Time dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get an error estimate.
hdop	No	numeric	Horizontal dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get a circular error estimate.
pdop	No	numeric	Spherical dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get an error estimate.
gdop	No	numeric	Hyperspherical dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get an error estimate.
satellites	Yes	list	List of satellite objects in skyview
 * </pre>
 */
class FANCYGPSDCLIENT_API Sky: public Message {
	Fancy::String::ptr_t tag;
	Fancy::String::ptr_t device;
	Fancy::Number::ptr_t tdop;
	Fancy::Number::ptr_t vdop;
	Fancy::Number::ptr_t hdop;
	Fancy::Number::ptr_t pdop;
	Fancy::Number::ptr_t xdop;
	Fancy::Number::ptr_t ydop;
	Fancy::Number::ptr_t gdop;
	Fancy::List::ptr_t satellites;

public:
	typedef Fancy::ObjPtr<Sky> ptr_t;
	static ptr_t newInstance();
	static Fancy::Serializable::ptr_t newSerializableInstance();
	static const char* getSerialID_s();
	static const char* getSuperSerialID_s();
	const char* getSerialID() const;
	const char* getSuperSerialID() const;
	void writeFields(const ObjPtr<Serializer>& serializer) const;
	ObjPtr<Serializable> readFields(const ObjPtr<Serializer>& serializer,int64_t serialVersionUID);

	Fancy::String::ptr_t getTag() const;
	void setTag(const Fancy::String::ptr_t &tag);
	Fancy::String::ptr_t getDevice() const;
	void setDevice(const Fancy::String::ptr_t &device);
	const Fancy::Number::ptr_t& getGdop() const;
	void setGdop(const Fancy::Number::ptr_t& gdop);
	const Fancy::Number::ptr_t& getHdop() const;
	void setHdop(const Fancy::Number::ptr_t& hdop);
	const Fancy::Number::ptr_t& getPdop() const;
	void setPdop(const Fancy::Number::ptr_t& pdop);
	const Fancy::List::ptr_t& getSatellites() const;
	void setSatellites(const Fancy::List::ptr_t& satellites);
	const Fancy::Number::ptr_t& getTdop() const;
	void setTdop(const Fancy::Number::ptr_t& tdop);
	const Fancy::Number::ptr_t& getVdop() const;
	void setVdop(const Fancy::Number::ptr_t& vdop);
	const Fancy::Number::ptr_t& getXdop() const;
	void setXdop(const Fancy::Number::ptr_t& xdop);
	const Fancy::Number::ptr_t& getYdop() const;
	void setYdop(const Fancy::Number::ptr_t& ydop);

protected:
	Sky();
	virtual ~Sky();
};

} /* namespace GpsdClient */
} /* namespace Fancy */

#endif /* FANCYSPSDCLIENTVERSION_H_ */
