/***********************************************************
 * $Id$
 *
 * FancyLibs GPSD Client
 *
 * Copyright (C) 2014 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSPSDCLIENTTPV_H_
#define FANCYSPSDCLIENTTPV_H_

#include <fancygpsdclientmessage.h>
#include <fancystring.h>
#include <fancyutctimestamp.h>


#define FANCYGPSDCLIENT_TPV_MODE_UNKNOWN 0
#define FANCYGPSDCLIENT_TPV_MODE_NOFIX   1
#define FANCYGPSDCLIENT_TPV_MODE_FIX_2D  2
#define FANCYGPSDCLIENT_TPV_MODE_FIX_3D  3


namespace Fancy {
namespace GpsdClient {

/**
 * <pre>
class	Yes	string	Fixed: "TPV"
tag	No	string	Type tag associated with this GPS sentence; from an NMEA device this is just the NMEA sentence type.
device	No	string	Name of originating device.
mode	Yes	numeric	NMEA mode: %d, 0=no mode value yet seen, 1=no fix, 2=2D, 3=3D.
time	No	string	Time/date stamp in ISO8601 format, UTC. May have a fractional part of up to .001sec precision. May be absent if mode is not 2 or 3.
ept	No	numeric	Estimated timestamp error (%f, seconds, 95% confidence). Present if time is present.
lat	No	numeric	Latitude in degrees: +/- signifies West/East. Present when mode is 2 or 3.
lon	No	numeric	Longitude in degrees: +/- signifies North/South. Present when mode is 2 or 3.
alt	No	numeric	Altitude in meters. Present if mode is 3.
epx	No	numeric	Longitude error estimate in meters, 95% confidence. Present if mode is 2 or 3 and DOPs can be calculated from the satellite view.
epy	No	numeric	Latitude error estimate in meters, 95% confidence. Present if mode is 2 or 3 and DOPs can be calculated from the satellite view.
epv	No	numeric	Estimated vertical error in meters, 95% confidence. Present if mode is 3 and DOPs can be calculated from the satellite view.
track	No	numeric	Course over ground, degrees from true north.
speed	No	numeric	Speed over ground, meters per second.
climb	No	numeric	Climb (positive) or sink (negative) rate, meters per second.
epd	No	numeric	Direction error estimate in degrees, 95% confidence.
eps	No	numeric	Speed error estinmate in meters/sec, 95% confidence.
epc	No	numeric	Climb/sink error estimate in meters/sec, 95% confidence.
 * </pre>
 */
class FANCYGPSDCLIENT_API Tpv: public Message {
	Fancy::String::ptr_t tag;
	Fancy::String::ptr_t device;
	Fancy::UtcTimestamp::ptr_t time;
	Fancy::Number::ptr_t ept;
	Fancy::Number::ptr_t lat;
	Fancy::Number::ptr_t lon;
	Fancy::Number::ptr_t alt;
	Fancy::Number::ptr_t epx;
	Fancy::Number::ptr_t epy;
	Fancy::Number::ptr_t epv;
	Fancy::Number::ptr_t track;
	Fancy::Number::ptr_t speed;
	Fancy::Number::ptr_t climb;
	Fancy::Number::ptr_t eps;
	int32_t mode;

public:
	typedef Fancy::ObjPtr<Tpv> ptr_t;
	static ptr_t newInstance();
	static Fancy::Serializable::ptr_t newSerializableInstance();
	static const char* getSerialID_s();
	static const char* getSuperSerialID_s();
	const char* getSerialID() const;
	const char* getSuperSerialID() const;
	void writeFields(const ObjPtr<Serializer>& serializer) const;
	ObjPtr<Serializable> readFields(const ObjPtr<Serializer>& serializer,
			int64_t serialVersionUID);

		Fancy::String::ptr_t getTag() const;
		void setTag(Fancy::String::ptr_t tag);
		Fancy::String::ptr_t getDevice() const;
		void setDevice(Fancy::String::ptr_t device);
		Fancy::UtcTimestamp::ptr_t getTime() const;
		void setTime(Fancy::UtcTimestamp::ptr_t time);
		void setEpt(const Fancy::Number::ptr_t & ept);
		Fancy::Number::ptr_t getEpt() const;
		void setLat(const Fancy::Number::ptr_t & lat);
		Fancy::Number::ptr_t getLat() const;
		void setLon(const Fancy::Number::ptr_t & lon);
		Fancy::Number::ptr_t getLon() const;
		void setAlt(const Fancy::Number::ptr_t & alt);
		Fancy::Number::ptr_t getAlt() const;
		void setEpx(const Fancy::Number::ptr_t & epx);
		Fancy::Number::ptr_t getEpx() const;
		void setEpy(const Fancy::Number::ptr_t & epy);
		Fancy::Number::ptr_t getEpy() const;
		void setEpv(const Fancy::Number::ptr_t & epc);
		Fancy::Number::ptr_t getEpv() const;
		void setTrack(const Fancy::Number::ptr_t & track);
		Fancy::Number::ptr_t getTrack() const;
		void setSpeed(const Fancy::Number::ptr_t & speed);
		Fancy::Number::ptr_t getSpeed() const;
		void setClimb(const Fancy::Number::ptr_t & climb);
		Fancy::Number::ptr_t getClimb() const;
		void setEps(const Fancy::Number::ptr_t & eps);
		Fancy::Number::ptr_t getEps() const;
		int32_t getMode() const;
		void setMode(int32_t mode);

protected:
	Tpv();
	virtual ~Tpv();
};

} /* namespace GpsdClient */
} /* namespace Fancy */

#endif /* FANCYSPSDCLIENTVERSION_H_ */
